@@ -393,6 +393,7 @@ Source *openSource(char *text)
 {
 static Source source;
 
+	source.fontSelectionSuffix = NULL;
 	source.extraData = NULL;
 	source.sourceInit = NULL;
 	source.sourceConversion = NULL;
@@ -402,12 +403,24 @@ static Source source;
 	source.sourceFinalize = NULL;
 	source.sourceConvertibleTextContext = NULL;
 
-	source.creator.major = source.creator.minor = 0;
+	source.creator.major = source.creator.minor = source.creator.subminor = 0;
 	strcpy(source.creator.name,"");
 	strcpy(source.creator.desc,"");
 	strncpy(source.creator.desc,text,MAXNAME);
-	sscanf(text,"%*s%s%d.%d",source.creator.name,&source.creator.major,&source.creator.minor);
-	source.creator.version = versionfromparts(source.creator.major,source.creator.minor);
+
+	source.creator.version = 0;
+
+	sscanf(text,"%*s%s",source.creator.name);
+
+	if (strcasecmp(source.creator.name,"htmldoc") == 0)
+	{
+		sscanf(text,"%*s%*s%d.%d.%d",&source.creator.major,&source.creator.minor,&source.creator.subminor);
+	}
+	else if (strcasecmp(source.creator.name,"mozilla") == 0)
+	{
+		sscanf(text,"%*s%*s%*s%*s (rv:%d.%d.%d",&source.creator.major,&source.creator.minor,&source.creator.subminor);
+	}
+	source.creator.version = versionfromparts(source.creator.major,source.creator.minor,source.creator.subminor);
 
 	if (verbose)
 		fprintf(stderr,"Source application %s %d.%d [%s]\n",
@@ -416,6 +429,10 @@ static Source source;
 	if (strcasecmp(source.creator.name,"mozilla") == 0)
 	{
 		source.creator.id = AUTOMOZILLA;
+		if (source.creator.version >= 0x010703)
+			source.fontSelectionSuffix = "Mfr";
+		else
+			source.fontSelectionSuffix = "findfont";
 		source.sourceInit = sourceInitMozillaNetscape;
 		source.sourceConversion = sourceConversionMozillaNetscape;
 		source.sourceGetFonts = sourceGetFontsMozillaNetscape;
@@ -427,6 +444,10 @@ static Source source;
 	else if (strcasecmp(source.creator.name,"htmldoc") == 0 && source.creator.version >= 0x010800)
 	{
 		source.creator.id = HTMLDOC;
+		if (source.creator.version >= 0x010818)
+			source.fontSelectionSuffix = "DF";
+		else
+			source.fontSelectionSuffix = "findfont";
 		source.sourceInit = sourceInitHtmlDoc;
 		source.sourceConversion = sourceConversionHtmlDoc;
 		source.sourceGetFonts = sourceGetFontsHtmlDoc;
@@ -438,6 +459,7 @@ static Source source;
 	else if (strcasecmp(source.creator.name,"htmldoc") == 0 && source.creator.version < 0x010800)
 	{
 		source.creator.id = HTMLDOC;
+		source.fontSelectionSuffix = "findfont";
 		source.sourceInit = sourceInitHtmlDoc;
 		source.sourceConversion = sourceConversionHtmlDoc;
 		source.sourceGetFonts = sourceGetFontsHtmlDoc;
@@ -979,7 +1001,7 @@ FILE	*out;
 			lastWordAt = ftell(out);
 			fputs(word,out);
 		}
-		else if (strwse2cmp("findfont",word) == 0)
+		else if (strwse2cmp(sourceglobal->fontSelectionSuffix,word) == 0)
 		{
 			i = sourceglobal->sourceGetFonts(sourceglobal,wordMemory(-1,NULL));
 
